@@ -214,7 +214,7 @@ cached_dir_lookup (const char *canonical)
     dir_cache = cached_dir_new ("/");
   dir = dir_cache;
 
-  g_assert (canonical != NULL && canonical[0] == '/');
+  g_assert (canonical != NULL && canonical[0] == G_DIR_SEPARATOR);
 
   menu_verbose ("Looking up cached dir \"%s\"\n", canonical);
 
@@ -314,20 +314,13 @@ cached_dir_add_subdir (CachedDir  *dir,
                        const char *path)
 {
   CachedDir *subdir;
-  GSList    *tmp;
 
-  tmp = dir->subdirs;
-  while (tmp != NULL)
+  subdir = find_subdir (dir, basename);
+
+  if (subdir != NULL)
     {
-      subdir = (CachedDir *) tmp->data;
-
-      if (strcmp (subdir->name, basename) == 0)
-        {
-	  subdir->deleted = FALSE;
-          return TRUE;
-        }
-
-      tmp = tmp->next;
+      subdir->deleted = FALSE;
+      return TRUE;
     }
 
   subdir = cached_dir_new (basename);
@@ -350,27 +343,21 @@ static gboolean
 cached_dir_remove_subdir (CachedDir  *dir,
                           const char *basename)
 {
-  GSList *tmp;
+  CachedDir *subdir;
 
-  tmp = dir->subdirs;
-  while (tmp != NULL)
+  subdir = find_subdir (dir, basename);
+
+  if (subdir != NULL)
     {
-      CachedDir *subdir = tmp->data;
+      subdir->deleted = TRUE;
 
-      if (strcmp (subdir->name, basename) == 0)
+      if (subdir->references == 0)
         {
-	  subdir->deleted = TRUE;
-
-	  if (subdir->references == 0)
-	    {
-	      cached_dir_free (subdir);
-	      dir->subdirs = g_slist_delete_link (dir->subdirs, tmp);
-	    }
-
-          return TRUE;
+          cached_dir_free (subdir);
+          dir->subdirs = g_slist_remove (dir->subdirs, subdir);
         }
 
-      tmp = tmp->next;
+      return TRUE;
     }
 
   return FALSE;
@@ -509,8 +496,8 @@ cached_dir_load_entries_recursive (CachedDir  *dir,
   cached_dir_ensure_monitor (dir, dirname);
 
   fullpath = g_string_new (dirname);
-  if (fullpath->str[fullpath->len - 1] != '/')
-    g_string_append_c (fullpath, '/');
+  if (fullpath->str[fullpath->len - 1] != G_DIR_SEPARATOR)
+    g_string_append_c (fullpath, G_DIR_SEPARATOR);
 
   fullpath_len = fullpath->len;
 
@@ -874,7 +861,7 @@ entry_directory_foreach_recursive (EntryDirectory            *ed,
       CachedDir *subdir = tmp->data;
 
       g_string_append (relative_path, subdir->name);
-      g_string_append_c (relative_path, '/');
+      g_string_append_c (relative_path, G_DIR_SEPARATOR);
 
       if (!entry_directory_foreach_recursive (ed,
                                               subdir,
